"""
Program: hangman.py
Author: Mark Clarkson
Date: January 2013
Description: A (fairly) simple hangman game, using the Turtle module to draw
Notes:
On a wrong letter, a turtle window appears
Click on the turtle window once drawn to go back to the game
Guesses are not case sensitive
"""

import turtle
from sys import stdout
from time import sleep

####################
# Method to print a hangman
####################

def draw(guesses):

    # Create a screen and a turtle
    window = turtle.Screen()
    timmy = turtle.Turtle()

    # Draw the first line if the player has had more than one go
    if guesses > 0:
        timmy.forward(100)

    # Draw the second line, but only if the player has had 2+ goes
    if guesses > 1:
        timmy.left(90)
        timmy.forward(200)

    # Etc...
    if guesses > 2:
        timmy.left(90)
        timmy.forward(50)

    if guesses > 3:
        timmy.left(90)
        timmy.forward(30)

    if guesses > 4:
        timmy.speed(0)
        timmy.right(90)
        for i in range(135):
            timmy.forward(1)
            timmy.left(4)

    if guesses > 5:
        timmy.speed(2)
        timmy.right(90)
        timmy.forward(50)

    if guesses > 6:
        timmy.right(30)
        timmy.forward(50)
        timmy.back(50)
        timmy.left(60)
        timmy.forward(50)
        timmy.back(50)
        timmy.right(30)

    if guesses > 7:
        timmy.back(25)
        timmy.right(90)
        timmy.forward(30)
        timmy.right(180)
        timmy.forward(60)

    window.exitonclick()


####################
# End of draw() method
####################



####################
# Ask the user for a word to guess
####################

def setWord():
    word = input("Enter your chosen word: ")
    for i in range(20):
        print("\n")
    return word.upper()

####################
# Display the contents of an array on one line
####################

def displayArray(array):
    for i in range (len(array)):
        print(array[i], end="")
    print("\n")


####################
# Ask the user to guess a letter and react accordingly
####################

def takeAGuess(lettersTried,currentState,word):

    # Declare control variable
    
    valid = False

    # Get a valid letter from the user
    
    while valid == False:
        guessAsChar = input("Guess a letter: ").upper()
        if len(guessAsChar) == 1:
            guessAsInt = ord(guessAsChar)-65
            if lettersTried[guessAsInt] == "*":
               valid = True
            else:
               print("You've already guessed the letter " + guessAsChar)
        else:
               print("Error, invalid guess. Try again.")

    lettersTried[guessAsInt] = guessAsChar

    
    # Check if letter is present in the answer

    valid = False
    
    for i in range(len(currentState)):
        if word[i] == guessAsChar:
            currentState[i] = word[i]
            valid = True

        
    return(lettersTried,currentState,valid)


####################
# Set the current state of the guess back to blank
####################

def resetCurrentState(word):
    currentState = ["*"] * len(word)
    for i in range(len(word)):
        if word[i] == ' ':
            currentState[i] = " "
    return currentState


####################
# Check to see if currentState is correct
####################

def compare(word,currentState):
    identical = True
    for i in range(len(word)):
        if word[i] != currentState[i]:
            identical = False

    return identical
            

####################
# Main method
####################

# Declare the array to store which characters have been tried

lettersTried = ["*"] * 26

#set your word

completeWord = setWord()

# Declare the array to store the current state of the guess
currentState = resetCurrentState(completeWord)

# Set key variables to control the flow of the game
guess = 0
won = False

# Main loop

while guess < 8 and won == False:
    print("\nLetters guessed so far:")
    displayArray(lettersTried)
    print("\nCurrent state of your guess:")
    displayArray(currentState)
    
    lettersTried,currentState,correctLetter = takeAGuess(lettersTried,currentState,completeWord)
    if correctLetter != True:
        guess = guess + 1
        print("Incorrect!")
        draw(guess)
    else:
        won = compare(completeWord,currentState)

if won == True:
    displayArray(currentState)
    print("Congratulations and well done!")
elif guess == 8:
    print("Sorry, you lost! The correct answer was " + completeWord)
else:
    ("Oops, something went wrong!")




